---
title: <span class="badge object-type-scalar"></span> RecordsPerMinute
---
# <span class="badge object-type-scalar"></span> RecordsPerMinute

Throughput: records/min (rpm)

## Definition

```python
# Throughput: records/min (rpm)
RecordsPerMinute: typing.Literal["recpm"] = "recpm"
```
